@@ -17,7 +17,7 @@ You can consult the GNU General Public License on http://www.gnu.org/licenses/gp
 '''
 
 
-from ._version import VERSION, __ver__, __version__
+from ._version import VERSION, __ver__, __version__, DATE, __date__
 
 from .dcom import COM_SPEEDS, DComError
 from .common import DApi2Side, DApiException, REG_SIZE, REG_MAX_VALUE, dateToWord, versionToStr, versionToWord,\
@@ -34,7 +34,7 @@ from .dmsg import  MsgType, MsgReaderState,ACK_CHAR, NAK_CHAR, CRC_INITIAL,\
     
 from .dreg import BaseRegElement, RegContainer, RegContainerReader, Register, RegGroup, RegisterArray
 
-from .dapi2 import DApi2, DApiAccessLevel
+from .dapi2 import DApi2, DApiAccessLevel, DApiAdditionalBoard
 from .dcom import DSerial, DSocket, DComTracingDirection, TRACE_INGOING_RAW_FMT, TRACE_OUTGOING_RAW_FMT,\
         TRACE_INGOING_NORMAL_FMT, TRACE_OUTGOING_NORMAL_FMT, TRACE_INGOING_COLOR, TRACE_OUTGOING_COLOR, TRACE_RESET_COLOR,\
         TRACE_INERROR_COLOR, TRACE_OUTERROR_COLOR
