@@ -4,6 +4,7 @@
 :date: Created on 16 juin 2021
 '''
 from .common import BaseBoardItem, CalibrationProcessState
+from ..dreg.register import Register
 
 
 
@@ -11,15 +12,16 @@ class BaseAnalogInput(BaseBoardItem):
     CAL_NEEDED = False
     FMT = '{0:0.0f}%'
     FACTOR = 1/100
-    MAX = 100.0
-    CAL_INDEX = 0
-    REG = None
-    NAME = 'unknow'
-    def __init__(self, board):
-        super().__init__(board, self.NAME)
-        self._reg = self.board.regs.getRegister(self.REG)
+
+    def __init__(self, board, name, reg, maximum=100):
+        super().__init__(board, name)
+        self.maximum = maximum
+        if not isinstance(reg, Register):
+            self._reg = self.board.regs.getRegister(reg)
+        else:
+            self._reg = reg
         self.cal_process_state = CalibrationProcessState.IDLE
-    
+
     def isCalibrated(self):
         return self._board.regs.sfr.value & (1<<(1+self.CAL_INDEX))
 
@@ -28,13 +30,13 @@ class BaseAnalogInput(BaseBoardItem):
             self._board.readReg(self.reg)
         return self._reg.value
 
-    
+
     def getValue(self, refresh=False):
         return float(self.getRawValue(refresh)) * self.FACTOR
-    
+
     def calibration(self, phase, param=None):
         assert False, 'TODO:calibration'
-        
+
     @property
     def reg(self):
         return self._reg
@@ -44,31 +46,34 @@ class BaseAnalogInput(BaseBoardItem):
     @property
     def value(self):
         return self.getValue()
-    
-class PressureSensor(BaseAnalogInput):
-    NAME = 'Pressure'
-    REG = 'prcr'
-    CAL_NEEDED = True
-    CAL_INDEX = 1
-    
-class ElectricalSensor(BaseAnalogInput):
+
+class PercentSensor(BaseAnalogInput):
     pass
 
-class Analog0Sensor(ElectricalSensor):
-    NAME = 'Analog #0'
-    REG = 'an0r'
+class PressureSensor(BaseAnalogInput):
+    CAL_NEEDED = True
+    CAL_INDEX = 1
 
-class Analog1Sensor(ElectricalSensor):
-    NAME = 'Analog #1'
-    REG = 'an1r'
+    def __init__(self, board, name, reg, maximum=4.0):
+        super().__init__(board, name, reg, maximum)
 
-class ReferenceSensor(BaseAnalogInput):
-    NAME = 'Reference'
-    REG = 'elcr'
 
-class PowerSupply(BaseAnalogInput):
-    NAME = 'Power supply'
+class VoltageSensor(BaseAnalogInput):
     FACTOR = 1/1000
     FMT = '{0:0.02f}V'
-    MAX = 36.00
-    REG = 'psvr'
+
+    def __init__(self, board, name, reg, maximum=5.0):
+        super().__init__(board, name, reg, maximum)
+
+class PowerSupplySensor(VoltageSensor):
+    def __init__(self, board, name, reg, maximum=42):
+        super().__init__(board, name, reg, maximum)
+
+class CurrentSensor(BaseAnalogInput):
+    FACTOR = 1/1000
+    FMT = '{0:0.02f}A'
+
+    def __init__(self, board, name, reg, maximum=8.0):
+        super().__init__(board, name, reg, maximum)
+
+
