@@ -11,7 +11,7 @@ from dapi2.dreg.base import DRegAccess
 
 
 class DebugValue(BaseBoardItem):
-    
+
     def __init__(self, board, reg, index=None, size=16):
         BaseBoardItem.__init__(self, board, name=reg.name)
         self._reg = reg
@@ -22,33 +22,37 @@ class DebugValue(BaseBoardItem):
         self._reg.changed.connect(self.onRegisterChange)
         if self._reg.isDefined():
             self.onRegisterChange(self._reg, self._reg.value, self._reg.value)
-    
+
     def __getitem__(self, index):
         return self.values[index]
-    
+
     def __len__(self):
         return len(self.values)
-    
+
     def setSize(self, size):
         self._size = size
         if self._size < len(self):
             self.values = self.values[:self._size]
-   
+
     def connect(self, callback):
         if all(x != callback for x in self._callback_list):
-            self._callback_list.append(callback)            
+            self._callback_list.append(callback)
 
     def disconnect(self, callback):
-        self._callback_list.remove(callback) 
+        self._callback_list.remove(callback)
 
     def onRegisterChange(self, reg, old_value=None, new_value=None):
         self.board.log.debug('DebugValue.onRegisterChange')
         if new_value is None:
             new_value = reg.value
         self.values = ([new_value]+self.values)[:self._size]
-        
+
         for func in self._callback_list:
-            func(self)      
+            func(self)
+
+    def setValue(self, value):
+        self._reg.internalSet(value, True)
+        self.board.dapi.syncRegs()
 
     @property
     def reg(self):
@@ -69,6 +73,10 @@ class DebugValue(BaseBoardItem):
             return self.values[0]
         except IndexError:
             return None
-        
-    
-    
\ No newline at end of file
+
+    @value.setter
+    def value(self, value):
+        self.setValue(value)
+
+
+
