@@ -4,10 +4,11 @@
 :date: 2021-02-24 Creation
 '''
 
-from .base import BaseDBoard, DBoardPreferredDapiMode
+from .base import DBoard, DBoardPreferredDapiMode
 
 
-class GenericBoard(BaseDBoard):
+
+class GenericBoard(DBoard):
     '''Generic class board.
     
     This class is used when the type of card could not be determined.
