@@ -12,6 +12,7 @@ from enum import IntEnum
 from ..common import DApi2Side, DApiException
 from ..dmsg.reader import MsgReader
 from ..dmsg.writer import MsgWriter
+from ..signal import DBoolSignal
 
 
 
@@ -76,6 +77,8 @@ class BaseDCom(object):
         self.trace_callback = trace_callback
         self.start_time = time.time()
         self.response_timeout = response_timeout
+        self._connection_changed = DBoolSignal()
+        
         
     def __str__(self):
         try:
@@ -88,11 +91,11 @@ class BaseDCom(object):
         
     def open(self):
         '''Open communications'''
-        pass
+        self._connection_changed.emit(True)
     
     def close(self):
         '''Close communications'''
-        pass
+        self._connection_changed.emit(False)
 
     def isOpen(self):
         '''Check if serial port is open.
@@ -175,5 +178,7 @@ class BaseDCom(object):
             
         self.trace_callback(time.time()-self.start_time, DComTracingDirection.INGOING, buf, msg)
 
-            
+    @property
+    def connectionChanged(self):
+        return self._connection_changed
             
\ No newline at end of file
