@@ -99,12 +99,13 @@ class DSerial(BaseDCom):
             time.sleep(1)
             self.log.warning('Attempting until the serial port is open ({0:d}/10) ...'.format(i))
         self.log.info( "Serial port is open on {0!s}@{1:d}bd".format(self.serial.port, self.serial.baudrate) )
-            
+        super().open()    
         
     def close(self):
         '''Close serial port'''
         self.log.info('Close serial to port {0!s}'.format(self.serial.port))
         self.serial.close()
+        super().close()
 
     def reset(self, state=DSerialState.OK):
         '''Resets the serial communications
