@@ -1,9 +1,9 @@
-'''The `dreg` module implements the registers management. 
+'''The `dreg` module implements the registers management.
 
 :author: F. Voillat
 '''
 
-from .base import BaseRegElement, DRegException, DRegAccess
+from .base import BaseRegElement, DRegException, DRegAccess, DRegType
 from .container import RegContainer
 from .group import RegGroup
 from .register import Register, ReservedRegister, RegisterArray, BitFieldRegister, RegBit, RegBitChoice, ReservedRegBit
