@@ -8,7 +8,10 @@
 class DSignal(object):
     
     def __init__(self, name=None):
-        self.name = name
+        if name is None:
+            self.name = self.__class__.__name__  
+        else:
+            self.name = name
         self._callbacks = []
 
 
@@ -35,4 +38,9 @@ class DSignal(object):
         return self._callbacks
     
   
+class DBoolSignal(DSignal):
+
+    def emit(self, state):
+        for callback in self.callbacks:
+            callback(state)
 
